%global sphinx_user sphinx
%global sphinx_group sphinx
%global sphinx_home %{_localstatedir}/lib/sphinx

Name:           sphinx
Version:        2.2.11
Release:        2.1
Summary:        Free open-source SQL full-text search engine
Group:          Applications/Text
License:        GPLv2+
URL:            http://sphinxsearch.com

Source0:        http://sphinxsearch.com/files/%{name}-%{version}-release.tar.gz
Source1:        searchd.service
Patch0:         %{name}-2.0.3-fix_static.patch
Patch1:         %{name}-2.0.3-default_listen.patch
Patch2:         %{name}-aarch64.patch

BuildRequires:  expat-devel
BuildRequires:  mysql-devel
BuildRequires:  postgresql-devel
BuildRequires:  systemd
BuildRequires:	libstemmer-devel

# for fix-ups
BuildRequires:  dos2unix

Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

# Users and groups
Requires(pre): shadow-utils
       

%description
Sphinx is a full-text search engine, distributed under GPL version 2.
Commercial licensing (e.g. for embedded use) is also available upon request.

Generally, it's a standalone search engine, meant to provide fast,
size-efficient and relevant full-text search functions to other
applications. Sphinx was specially designed to integrate well with SQL
databases and scripting languages.

Currently built-in data source drivers support fetching data either via
direct connection to MySQL, or PostgreSQL, or from a pipe in a custom XML
format. Adding new drivers (e.g. to natively support some other DBMSes) is
designed to be as easy as possible.

Search API is natively ported to PHP, Python, Perl, Ruby, Java, and also
available as a pluggable MySQL storage engine. API is very lightweight so
porting it to new language is known to take a few hours.

As for the name, Sphinx is an acronym which is officially decoded as SQL
Phrase Index. Yes, I know about CMU's Sphinx project.


%package -n libsphinxclient
Summary:        Pure C searchd client API library
Group:          Development/Libraries


%description -n libsphinxclient
Pure C searchd client API library
Sphinx search engine, http://sphinxsearch.com/


%package -n libsphinxclient-devel
Summary:        Development libraries and header files for libsphinxclient
Group:          Development/Libraries
Requires:       libsphinxclient = %{version}-%{release}
Requires:	libstemmer-devel

%description -n libsphinxclient-devel
Pure C searchd client API library
Sphinx search engine, http://sphinxsearch.com/


%package java
Summary: Java API for Sphinx
Group: Development/Libraries
BuildRequires: java-devel
Requires: java
Requires: jpackage-utils


%description java
This package provides the Java API for Sphinx,
the free, open-source full-text search engine,
designed with indexing database content in mind.


%package php
Summary: PHP API for Sphinx
Group: Development/Libraries
Requires: php-common >= 5.1.6


%description php
This package provides the PHP API for Sphinx,
the free, open-source full-text search engine,
designed with indexing database content in mind.


%prep
%setup -qn %{name}-%{version}-release
%patch0 -p1 -b .fix_static
%patch1 -p1 -b .default_listen
%patch2 -p1 -b .aarch64

# Fix wrong-file-end-of-line-encoding
for f in \
    api/java/mk.cmd \
    api/ruby/test.rb \
    api/ruby/spec/sphinx/sphinx_test.sql \
; do
  dos2unix ${f}
done



%build
%if 0%{?__isa_bits} == 64
%configure --sysconfdir=%{_sysconfdir}/sphinx --with-mysql --with-pgsql --with-libstemmer --enable-id64 
%else
%configure --sysconfdir=%{_sysconfdir}/sphinx --with-mysql --with-pgsql --with-libstemmer
%endif

make %{?_smp_mflags}

# Build libsphinxclient
pushd api/libsphinxclient
    %configure
    make #%{?_smp_mflags}
popd


# make the java api
make -C api/java 


%install
make install DESTDIR=$RPM_BUILD_ROOT INSTALL="%{__install} -p -c"

install -p -D -m 0755 %{SOURCE1} $RPM_BUILD_ROOT%{_unitdir}/searchd.service

# Create /var/log/sphinx
mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/log/sphinx

# Create /var/run/sphinx
mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/run/sphinx

# Create /var/lib/sphinx
mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/lib/sphinx

# Create sphinx.conf
cp $RPM_BUILD_ROOT%{_sysconfdir}/sphinx/sphinx-min.conf.dist \
    $RPM_BUILD_ROOT%{_sysconfdir}/sphinx/sphinx.conf
    
# Modify sphinx.conf
sed -i 's|/var/log/searchd.log|%{_localstatedir}/log/sphinx/searchd.log|g' \
    $RPM_BUILD_ROOT%{_sysconfdir}/sphinx/sphinx.conf

sed -i 's|/var/log/query.log|%{_localstatedir}/log/sphinx/query.log|g' \
    $RPM_BUILD_ROOT%{_sysconfdir}/sphinx/sphinx.conf

sed -i 's|/var/log/searchd.pid|%{_localstatedir}/run/sphinx/searchd.pid|g' \
    $RPM_BUILD_ROOT%{_sysconfdir}/sphinx/sphinx.conf

sed -i 's|/var/data|%{_localstatedir}/lib/sphinx|g' \
    $RPM_BUILD_ROOT%{_sysconfdir}/sphinx/sphinx.conf

# Create /etc/logrotate.d/sphinx
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d
cat > $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/sphinx << EOF
%{_localstatedir}/log/sphinx/*.log {
       weekly
       rotate 10
       copytruncate
       delaycompress
       compress
       notifempty
       missingok
}
EOF

# Create /etc/logrotate.d/sphinx                                                                                         
mkdir -p $RPM_BUILD_ROOT%{_tmpfilesdir}
cat > $RPM_BUILD_ROOT%{_tmpfilesdir}/%{name}.conf << EOF
d %{_localstatedir}/run/sphinx 755 sphinx root -
EOF

# Install libsphinxclient
pushd api/libsphinxclient/
    make install DESTDIR=$RPM_BUILD_ROOT INSTALL="%{__install} -p -c"
popd

# install the java api
mkdir -p $RPM_BUILD_ROOT%{_javadir}
install -m 0644 api/java/%{name}api.jar \
    $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar

# convenience symlinks
pushd $RPM_BUILD_ROOT%{_javadir}
    ln -s %{name}-%{version}.jar %{name}.jar
    ln -s %{name}-%{version}.jar %{name}api.jar
popd

# install the php api
# "Non-PEAR PHP extensions should put their Class files in /usr/share/php."
# - http://fedoraproject.org/wiki/Packaging:PHP
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/php
install -m 0644 api/%{name}api.php $RPM_BUILD_ROOT%{_datadir}/php

# clean-up .la archives
find $RPM_BUILD_ROOT -name '*.la' -exec rm -f {} ';'

# clean-up .a archives
find $RPM_BUILD_ROOT -name '*.a' -exec rm -f {} ';'


%pre
getent group %{sphinx_group} >/dev/null || groupadd -r %{sphinx_group}
getent passwd %{sphinx_user} >/dev/null || \
useradd -r -g %{sphinx_group} -d %{sphinx_home} -s /bin/bash \
-c "Sphinx Search" %{sphinx_user}
exit 0

%post
%systemd_post searchd.service

%preun
%systemd_preun searchd.service

%post -p /sbin/ldconfig -n libsphinxclient

%postun 
%systemd_postun_with_restart searchd.service


%posttrans
chown -R %{sphinx_user}:root %{_localstatedir}/log/sphinx/
chown -R %{sphinx_user}:root %{_localstatedir}/run/sphinx/
chown -R %{sphinx_user}:root %{_localstatedir}/lib/sphinx/

%triggerun -- sphinx < 2.0.3-1
# Save the current service runlevel info
# User must manually run systemd-sysv-convert --apply httpd
# to migrate them to systemd targets
/usr/bin/systemd-sysv-convert --save searchd >/dev/null 2>&1 ||:

# Run these because the SysV package being removed won't do them
/sbin/chkconfig --del searchd >/dev/null 2>&1 || :
/bin/systemctl try-restart searchd.service >/dev/null 2>&1 || :


%files
%doc COPYING doc/sphinx.txt sphinx-min.conf.dist sphinx.conf.dist example.sql
%dir %{_sysconfdir}/sphinx
%config(noreplace) %{_sysconfdir}/sphinx/sphinx.conf
%exclude %{_sysconfdir}/sphinx/*.conf.dist
%exclude %{_sysconfdir}/sphinx/example.sql
%{_unitdir}/searchd.service
%config(noreplace) %{_sysconfdir}/logrotate.d/sphinx
%{_tmpfilesdir}/%{name}.conf
%{_bindir}/*
%dir %attr(0755, %{sphinx_user}, root) %{_localstatedir}/log/sphinx
%dir %attr(0755, %{sphinx_user}, root) %{_localstatedir}/run/sphinx
%dir %attr(0755, %{sphinx_user}, root) %{_localstatedir}/lib/sphinx
%{_mandir}/man1/*

%files -n libsphinxclient
%doc COPYING api/java api/ruby api/*.php api/*.py api/libsphinxclient/README
%{_libdir}/libsphinxclient-0*.so

%files -n libsphinxclient-devel
%{_libdir}/libsphinxclient.so
%{_includedir}/*

%files java
%doc api/java/README COPYING
%{_javadir}/*

%files php
%doc COPYING
%{_datadir}/php/*

%changelog
* Fri Aug 19 2016 cs@linux-administrator.com
- initial import
